==> eiffelstudio-18.01.10.1424.tar: F_code/C7/ew315.c <==
/*
 * Code for class EW_EIFFEL_COMPILATION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew315.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_COMPILATION}.make */
void F907_6334 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 906, Current, 0, 4, 12473);
	RTHOOK(1);
	F904_6307(Current, arg1, arg2, arg3, NULL, NULL, arg4);
	RTHOOK(2);
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.next_compile_result_type */
EIF_REFERENCE F907_6335 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("next_compile_result_type", 906, Current, 0, 0, 12474);
	RTGC;
	RTHOOK(1);
	RTCT0("callable", EX_CHECK);
		RTCF0;
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {EW_EIFFEL_COMPILATION}.next_compile_result */
EIF_REFERENCE F907_6336 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("next_compile_result", 906, Current, 0, 0, 12475);
	RTGC;
	RTHOOK(1);
	Result = F904_6314(Current);
	RTHOOK(2);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R4319[Dtype(Result)-859])(RTCW(Result));
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = F904_6320(Current);
		F860_5800(RTCW(Result), tr1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_COMPILATION}.resume */
void F907_6337 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("resume", 906, Current, 0, 0, 12476);
	RTGC;
	RTHOOK(1);
	tr1 = RTMS_EX_H("\012",1,10);
	F904_6310(Current, tr1);
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.quit */
void F907_6338 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("quit", 906, Current, 0, 0, 12477);
	RTGC;
	RTHOOK(1);
	F904_6310(Current, *(EIF_REFERENCE *)(Current + _REFACS_6_));
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.abort */
void F907_6339 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLIU(2);
	
	RTEAA("abort", 906, Current, 1, 0, 12478);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_)) {
		RTHOOK(2);
		F907_6338(Current);
		RTHOOK(3);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4738[Dtype(Current)-903])(Current);
	}
	RTHOOK(4);
	F904_6312(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.terminate */
void F907_6340 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE loc1 = (EIF_REFERENCE) 0;
	RTLD;
	
	RTLI(2);
	RTLR(0,Current);
	RTLR(1,loc1);
	RTLIU(2);
	
	RTEAA("terminate", 906, Current, 1, 0, 12479);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_)) {
		RTHOOK(2);
		F907_6338(Current);
		RTHOOK(3);
		loc1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4738[Dtype(Current)-903])(Current);
	}
	RTHOOK(4);
	F904_6311(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.read_chunk */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F907_6341 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_BOOLEAN EIF_VOLATILE loc1 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc5 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 EIF_VOLATILE loc6 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 EIF_VOLATILE loc7 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,loc5);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEAA("read_chunk", 906, Current, 7, 0, 12480);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(824, 0x00).id, 824, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F821_5222(RTCW(tr1), ((EIF_INTEGER_32) 128L));
		loc5 = (EIF_REFERENCE) tr1;
		RTHOOK(3);
		loc7 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		for (;;) {
			RTHOOK(4);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc7 == (EIF_CHARACTER_8) '\012') || *(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_)) || loc2)) break;
			RTHOOK(5);
			F904_6324(Current);
			RTHOOK(6);
			if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_)) {
				RTHOOK(7);
				loc7 = *(EIF_CHARACTER_8 *)(Current+ _CHROFF_7_0_);
				RTHOOK(8);
				if ((EIF_BOOLEAN)(loc7 != (EIF_CHARACTER_8) '\015')) {
					RTHOOK(9);
					F825_5473(RTCW(loc5), loc7);
					RTHOOK(10);
					loc6++;
					RTHOOK(11);
					loc3 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(832,F60_832,(Current)))+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(loc6 == ti4_1)) {
						tr1 = RTOSCF(832,F60_832,(Current));
						loc3 = F1_10(Current, loc5, tr1);
					}
					RTHOOK(12);
					loc4 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(833,F60_833,(Current)))+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(loc6 == ti4_1)) {
						tr1 = RTOSCF(833,F60_833,(Current));
						loc4 = F1_10(Current, loc5, tr1);
					}
					RTHOOK(13);
					loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) (loc3 || loc4);
				}
			}
		}
	}
	RTHOOK(14);
	if (loc2) {
		RTHOOK(15);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(16);
		if (loc3) {
			RTHOOK(17);
			tr1 = RTMS_EX_H("q\012",2,28938);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(18);
			tr1 = RTMS_EX_H("n\012",2,28170);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		}
	}
	RTHOOK(19);
	RTAR(Current, loc5);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc5;
	RTE_E
	RTXSC;
	RTHOOK(20);
	if ((EIF_BOOLEAN)(F116_1201(Current) == ((EIF_INTEGER_32) 21L))) {
		RTHOOK(21);
		loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(22);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(23);
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTHOOK(24);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

/* {EW_EIFFEL_COMPILATION}.quit_reply */
EIF_REFERENCE F907_6342 (EIF_REFERENCE Current)
{
	return *(EIF_REFERENCE *)(Current + _REFACS_6_);
}


void EIF_Minit315 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif

==> eiffelstudio-19.05.10.3187.tar: F_code/C7/ew315.c <==
/*
 * Code for class EW_EIFFEL_COMPILATION
 */

#include "eif_eiffel.h"
#include "../E1/estructure.h"
#include "../E1/eoffsets.h"

#include "ew315.h"

#ifdef __cplusplus
extern "C" {
#endif


#ifdef __cplusplus
}
#endif


#ifdef __cplusplus
extern "C" {
#endif

/* {EW_EIFFEL_COMPILATION}.make */
void F908_6391 (EIF_REFERENCE Current, EIF_REFERENCE arg1, EIF_REFERENCE arg2, EIF_REFERENCE arg3, EIF_REFERENCE arg4)
{
	GTCX
	RTEX;
	
	
	RTEAA("make", 907, Current, 0, 4, 12585);
	RTHOOK(1);
	F905_6364(Current, arg1, arg2, arg3, NULL, NULL, arg4);
	RTHOOK(2);
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.next_compile_result_type */
EIF_REFERENCE F908_6392 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("next_compile_result_type", 907, Current, 0, 0, 12586);
	RTGC;
	RTHOOK(1);
	RTCT0("callable", EX_CHECK);
		RTCF0;
	RTHOOK(2);
	RTLE;
	RTEE;
	return (EIF_REFERENCE) 0;
}

/* {EW_EIFFEL_COMPILATION}.next_compile_result */
EIF_REFERENCE F908_6393 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_BOOLEAN tb1;
	EIF_REFERENCE Result = ((EIF_REFERENCE) 0);
	
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,Result);
	RTLR(2,tr1);
	RTLIU(3);
	
	RTEAA("next_compile_result", 907, Current, 0, 0, 12587);
	RTGC;
	RTHOOK(1);
	Result = F905_6371(Current);
	RTHOOK(2);
	tb1 = (FUNCTION_CAST(EIF_BOOLEAN, (EIF_REFERENCE)) R1333[Dtype(RTCW(Result))-139])(Result);
	if ((EIF_BOOLEAN) !tb1) {
		RTHOOK(3);
		tr1 = F905_6377(Current);
		F140_1497(RTCW(Result), tr1);
	}
	RTHOOK(4);
	RTLE;
	RTEE;
	return Result;
}

/* {EW_EIFFEL_COMPILATION}.resume */
void F908_6394 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	RTLD;
	
	RTLI(2);
	RTLR(0,tr1);
	RTLR(1,Current);
	RTLIU(2);
	
	RTEAA("resume", 907, Current, 0, 0, 12588);
	RTGC;
	RTHOOK(1);
	tr1 = RTMS_EX_H("\012",1,10);
	F905_6367(Current, tr1);
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.quit */
void F908_6395 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTLD;
	
	RTLI(1);
	RTLR(0,Current);
	RTLIU(1);
	
	RTEAA("quit", 907, Current, 0, 0, 12589);
	RTGC;
	RTHOOK(1);
	F905_6367(Current, *(EIF_REFERENCE *)(Current + _REFACS_6_));
	RTHOOK(2);
	*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 0;
	RTHOOK(3);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.abort */
void F908_6396 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("abort", 907, Current, 0, 0, 12590);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_)) {
		RTHOOK(2);
		F908_6395(Current);
		RTHOOK(3);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4786[Dtype(Current)-905])(Current);
		{
			/* INLINED CODE (ANY.do_nothing) */
			tr2 = tr1;
			/* END INLINED CODE */
		}
		;
	}
	RTHOOK(4);
	F905_6369(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.terminate */
void F908_6397 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	EIF_REFERENCE tr1 = NULL;
	EIF_REFERENCE tr2 = NULL;
	RTLD;
	
	RTLI(3);
	RTLR(0,Current);
	RTLR(1,tr1);
	RTLR(2,tr2);
	RTLIU(3);
	
	RTEAA("terminate", 907, Current, 0, 0, 12591);
	RTGC;
	RTHOOK(1);
	if (*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_)) {
		RTHOOK(2);
		F908_6395(Current);
		RTHOOK(3);
		tr1 = (FUNCTION_CAST(EIF_REFERENCE, (EIF_REFERENCE)) R4786[Dtype(Current)-905])(Current);
		{
			/* INLINED CODE (ANY.do_nothing) */
			tr2 = tr1;
			/* END INLINED CODE */
		}
		;
	}
	RTHOOK(4);
	F905_6368(Current);
	RTHOOK(5);
	RTLE;
	RTEE;
}

/* {EW_EIFFEL_COMPILATION}.read_chunk */
#undef EIF_VOLATILE
#define EIF_VOLATILE volatile
void F908_6398 (EIF_REFERENCE Current)
{
	GTCX
	RTEX;
	RTED;
	EIF_BOOLEAN EIF_VOLATILE loc1 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc2 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc3 = (EIF_BOOLEAN) 0;
	EIF_BOOLEAN EIF_VOLATILE loc4 = (EIF_BOOLEAN) 0;
	EIF_REFERENCE EIF_VOLATILE loc5 = (EIF_REFERENCE) 0;
	EIF_INTEGER_32 EIF_VOLATILE loc6 = (EIF_INTEGER_32) 0;
	EIF_CHARACTER_8 EIF_VOLATILE loc7 = (EIF_CHARACTER_8) 0;
	EIF_REFERENCE EIF_VOLATILE saved_except = (EIF_REFERENCE) 0;
	EIF_REFERENCE  EIF_VOLATILE tr1 = NULL;
	EIF_INTEGER_32  EIF_VOLATILE ti4_1;
	EIF_BOOLEAN  EIF_VOLATILE tb1;
	RTLD;
	RTXD;
	
	RTLI(4);
	RTLR(0,loc5);
	RTLR(1,tr1);
	RTLR(2,Current);
	RTLR(3,saved_except);
	RTLIU(4);
	RTXSLS;
	
	RTEAA("read_chunk", 907, Current, 7, 0, 12592);
	RTGC;
	RTE_T
	RTHOOK(1);
	if ((EIF_BOOLEAN) !loc1) {
		RTHOOK(2);
		tr1 = RTLNS(eif_new_type(884, 0x00).id, 884, _OBJSIZ_1_1_0_3_0_0_0_0_);
		F883_5785(RTCW(tr1), ((EIF_INTEGER_32) 128L));
		loc5 = (EIF_REFERENCE) tr1;
		RTHOOK(3);
		loc7 = (EIF_CHARACTER_8) (EIF_CHARACTER_8) '\000';
		for (;;) {
			RTHOOK(4);
			if ((EIF_BOOLEAN) ((EIF_BOOLEAN) ((EIF_BOOLEAN)(loc7 == (EIF_CHARACTER_8) '\012') || *(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_)) || loc2)) break;
			RTHOOK(5);
			F905_6381(Current);
			RTHOOK(6);
			if ((EIF_BOOLEAN) !*(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_)) {
				RTHOOK(7);
				loc7 = *(EIF_CHARACTER_8 *)(Current+ _CHROFF_7_0_);
				RTHOOK(8);
				if ((EIF_BOOLEAN)(loc7 != (EIF_CHARACTER_8) '\015')) {
					RTHOOK(9);
					F885_5911(RTCW(loc5), loc7);
					RTHOOK(10);
					loc6++;
					RTHOOK(11);
					loc3 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(893,F72_893, (Current)))+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(loc6 == ti4_1)) {
						tr1 = RTOSCF(893,F72_893, (Current));
						tb1 = F883_5812(RTCW(loc5), tr1);
						loc3 = tb1;
					}
					RTHOOK(12);
					loc4 = '\0';
					ti4_1 = *(EIF_INTEGER_32 *)(RTCV(RTOSCF(894,F72_894, (Current)))+ _LNGOFF_1_1_0_2_);
					if ((EIF_BOOLEAN)(loc6 == ti4_1)) {
						tr1 = RTOSCF(894,F72_894, (Current));
						tb1 = F883_5812(RTCW(loc5), tr1);
						loc4 = tb1;
					}
					RTHOOK(13);
					loc2 = (EIF_BOOLEAN) (EIF_BOOLEAN) (loc3 || loc4);
				}
			}
		}
	}
	RTHOOK(14);
	if (loc2) {
		RTHOOK(15);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_1_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(16);
		if (loc3) {
			RTHOOK(17);
			tr1 = RTMS_EX_H("q\012",2,28938);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		} else {
			RTHOOK(18);
			tr1 = RTMS_EX_H("n\012",2,28170);
			RTAR(Current, tr1);
			*(EIF_REFERENCE *)(Current + _REFACS_6_) = (EIF_REFERENCE) tr1;
		}
	}
	RTHOOK(19);
	RTAR(Current, loc5);
	*(EIF_REFERENCE *)(Current + _REFACS_5_) = (EIF_REFERENCE) loc5;
	RTE_E
	RTXSC;
	RTHOOK(20);
	if ((EIF_BOOLEAN)(F130_1324(Current) == ((EIF_INTEGER_32) 21L))) {
		RTHOOK(21);
		loc1 = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(22);
		*(EIF_BOOLEAN *)(Current+ _CHROFF_7_2_) = (EIF_BOOLEAN) (EIF_BOOLEAN) 1;
		RTHOOK(23);
		RTER;
	}
	/* NOTREACHED */
	RTE_EE
	RTHOOK(24);
	RTEOK;
	RTLE;
}
#undef EIF_VOLATILE
#define EIF_VOLATILE

void EIF_Minit315 (void)
{
	GTCX
}


#ifdef __cplusplus
}
#endif
